Documentation
¶
Index ¶
Examples ¶
Constants ¶
const (
PKG4 = "PKG4"
)
Variables ¶
var ( ErrNodeIndex = errors.New("the node index provided does not exist / it exceeds the total number of nodes") ErrNodeParsed = errors.New("this node has already been parsed") ErrNodeFile = errors.New("this node has not been initialised properly with NewNode") ErrNodeNoChild = errors.New("this node does not have any children or it is not yet parsed") )
var (
ErrFileInvalid = errors.New("this file is not an NX (PKG4) file or it has not been initialised properly with NewFile")
)
var (
ErrStringIndex = errors.New("the string index provided exceeds the total number of string entries")
)
Functions ¶
This section is empty.
Types ¶
type BitmapNode ¶
type BitmapNode struct {
// contains filtered or unexported fields
}
type File ¶
type File struct {
Fn string
// contains filtered or unexported fields
}
func NewFile ¶
Example ¶
nxf, _ := NewFile(TestFile, false)
fmt.Printf("File name: '%s'", nxf.Fn)
Output: File name: '../data/Base.nx'
func (*File) GetString ¶
Example ¶
nxf, _ := NewFile(TestFile, true)
s, _ := nxf.GetString(6)
fmt.Printf("String entry #6: %s", s)
Output: String entry #6: Map
type Node ¶
type StringNode ¶
type StringNode struct {
// contains filtered or unexported fields
}
type VectorNode ¶
type VectorNode struct {
// contains filtered or unexported fields
}
Click to show internal directories.
Click to hide internal directories.